package VMOMI::EntityType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
